@@ -258,6 +258,15 @@ class CT(RegistroDecomp):
     def nome(self, nome: str):
         self._dados[2] = nome
 
+    @property
+    def estagio(self) -> str:
+        """
+        O estágio associado às propriedades cadastradas.
+
+        :return: O estágio como um `int`.
+        """
+        return self._dados[3]
+
     @property
     def inflexibilidades(self) -> List[float]:
         """
